%% 
%% This is file `latin1.def', generated 
%% on <1995/1/3> with the docstrip utility (2.2i).
%% 
%% The original source files were:
%% 
%% inputenc.dtx  (with options: `latin1')
%% 
%% Copyright (C) 1994 LaTeX3 project and Alan Jeffrey. 
%% All rights reserved. 
%% 
%% This file is part of LaTeX2e. 
%% ----------------------------- 
%% 
%% This is a generated file. 
%% 
%% No permission is granted to modify this file. 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
 \ProvidesFile{latin1.def}
   [1994/12/10 Input ecoding file.]
\ProvideTextCommandDefault{\textonequarter}{$\frac14$}
\ProvideTextCommandDefault{\textonehalf}{$\frac12$}
\ProvideTextCommandDefault{\textthreequarters}{$\frac34$}
\ProvideTextCommandDefault{\textregistered}{\textcircled{\textsc r}}
\providecommand{\mathdegree}{{{}^\circ}}
\providecommand{\mathordmasculine}{{{}^a}}
\providecommand{\mathordfeminine}{{{}^o}}
\providecommand{\mathonesuperior}{{{}^1}}
\providecommand{\mathtwosuperior}{{{}^2}}
\providecommand{\maththreesuperior}{{{}^3}}
\DeclareInputText{"A0}{~}
\DeclareInputText{"A1}{\textexclamdown}
\DeclareInputText{"A2}{\textcent}
\DeclareInputText{"A3}{\textsterling}
\DeclareInputText{"A4}{\textcurrency}
\DeclareInputText{"A5}{\textyen}
\DeclareInputText{"A6}{\textbrokenbar}
\DeclareInputText{"A7}{\S}
\DeclareInputText{"A8}{\"{}}
\DeclareInputText{"A9}{\copyright}
\DeclareInputMath{"AA}{\mathordmasculine}
\DeclareInputText{"AB}{\guillemotleft}
\DeclareInputMath{"AC}{\lnot}
\DeclareInputText{"AD}{\textendash}
\DeclareInputText{"AE}{\textregistered}
\DeclareInputText{"AF}{\={}}
\DeclareInputMath{"B0}{\mathdegree}
\DeclareInputMath{"B1}{\pm}
\DeclareInputMath{"B2}{\mathtwosuperior}
\DeclareInputMath{"B3}{\maththreesuperior}
\DeclareInputText{"B4}{\'{}}
\DeclareInputMath{"B5}{\mu}
\DeclareInputText{"B6}{\P}
\DeclareInputMath{"B7}{\cdot}
\DeclareInputText{"B8}{\c{}}
\DeclareInputMath{"B9}{\mathonesuperior}
\DeclareInputMath{"BA}{\mathordfeminine}
\DeclareInputText{"BB}{\guillemotright}
\DeclareInputMath{"BC}{\textonequarter}
\DeclareInputMath{"BD}{\textonehalf}
\DeclareInputMath{"BE}{\textthreequarters}
\DeclareInputText{"BF}{\textquestiondown}
\DeclareInputText{"C0}{\`A}
\DeclareInputText{"C1}{\'A}
\DeclareInputText{"C2}{\^A}
\DeclareInputText{"C3}{\~A}
\DeclareInputText{"C4}{\"A}
\DeclareInputText{"C5}{\AA}
\DeclareInputText{"C6}{\AE}
\DeclareInputText{"C7}{\c C}
\DeclareInputText{"C8}{\`E}
\DeclareInputText{"C9}{\'E}
\DeclareInputText{"CA}{\^E}
\DeclareInputText{"CB}{\"E}
\DeclareInputText{"CC}{\`I}
\DeclareInputText{"CD}{\'I}
\DeclareInputText{"CE}{\^I}
\DeclareInputText{"CF}{\"I}
\DeclareInputText{"D0}{\DH}
\DeclareInputText{"D1}{\~N}
\DeclareInputText{"D2}{\`O}
\DeclareInputText{"D3}{\'O}
\DeclareInputText{"D4}{\^O}
\DeclareInputText{"D5}{\~O}
\DeclareInputText{"D6}{\"O}
\DeclareInputMath{"D7}{\times}
\DeclareInputText{"D8}{\O}
\DeclareInputText{"D9}{\`U}
\DeclareInputText{"DA}{\'U}
\DeclareInputText{"DB}{\^U}
\DeclareInputText{"DC}{\"U}
\DeclareInputText{"DD}{\'Y}
\DeclareInputText{"DE}{\TH}
\DeclareInputText{"DF}{\ss}
\DeclareInputText{"E0}{\`a}
\DeclareInputText{"E1}{\'a}
\DeclareInputText{"E2}{\^a}
\DeclareInputText{"E3}{\~a}
\DeclareInputText{"E4}{\"a}
\DeclareInputText{"E5}{\aa}
\DeclareInputText{"E6}{\ae}
\DeclareInputText{"E7}{\c c}
\DeclareInputText{"E8}{\`e}
\DeclareInputText{"E9}{\'e}
\DeclareInputText{"EA}{\^e}
\DeclareInputText{"EB}{\"e}
\DeclareInputText{"EC}{\`\i}
\DeclareInputText{"ED}{\'\i}
\DeclareInputText{"EE}{\^\i}
\DeclareInputText{"EF}{\"\i}
\DeclareInputText{"F0}{\dh}
\DeclareInputText{"F1}{\~n}
\DeclareInputText{"F2}{\`o}
\DeclareInputText{"F3}{\'o}
\DeclareInputText{"F4}{\^o}
\DeclareInputText{"F5}{\~o}
\DeclareInputText{"F6}{\"o}
\DeclareInputMath{"F7}{\div}
\DeclareInputText{"F8}{\o}
\DeclareInputText{"F9}{\`u}
\DeclareInputText{"FA}{\'u}
\DeclareInputText{"FB}{\^u}
\DeclareInputText{"FC}{\"u}
\DeclareInputText{"FD}{\'y}
\DeclareInputText{"FE}{\th}
\DeclareInputText{"FF}{\"y}
\endinput
%% 
%% End of file `latin1.def'.
