%% 
%% This is file `OMSenc.def', generated 
%% on <1995/1/3> with the docstrip utility (2.2i).
%% 
%% The original source files were:
%% 
%% ltoutenc.dtx  (with options: `OMS')
%% 
%% Copyright (C) 1994 LaTeX3 project, Frank Mittelbach, Rainer Schoepf 
%% and Alan Jeffrey. 
%% All rights reserved. 
%% 
%% This file is part of LaTeX2e. 
%% ----------------------------- 
%% 
%% This is a generated file. 
%% 
%% No permission is granted to modify this file. 
%% 
%%% File: ltoutenc
\ProvidesFile{OMSenc.def}[1994/12/14 Standard LaTeX file]
\DeclareFontEncoding{OMS}{}{}
\DeclareTextSymbol{\textbraceleft}{OMS}{"66}
\DeclareTextSymbol{\textbraceright}{OMS}{"67}
\DeclareTextSymbol{\textbullet}{OMS}{"0F}
\DeclareTextSymbol{\textdaggerdbl}{OMS}{"7A}
\DeclareTextSymbol{\textdagger}{OMS}{"79}
\DeclareTextSymbol{\textparagraph}{OMS}{"7B}
\DeclareTextSymbol{\textperiodcentered}{OMS}{"01}
\DeclareTextSymbol{\textsection}{OMS}{"78}
\DeclareTextCommand{\textcircled}{OMS}[1]{{%
   \ooalign{%
      \hfil \raise .07ex\hbox {\upshape#1}\hfil \crcr
      \char"0D
   }%
}}
\endinput
%% 
%% End of file `OMSenc.def'.
