%% 
%% This is file `OMLenc.def', generated 
%% on <1995/1/3> with the docstrip utility (2.2i).
%% 
%% The original source files were:
%% 
%% ltoutenc.dtx  (with options: `OML')
%% 
%% Copyright (C) 1994 LaTeX3 project, Frank Mittelbach, Rainer Schoepf 
%% and Alan Jeffrey. 
%% All rights reserved. 
%% 
%% This file is part of LaTeX2e. 
%% ----------------------------- 
%% 
%% This is a generated file. 
%% 
%% No permission is granted to modify this file. 
%% 
%%% File: ltoutenc
\ProvidesFile{OMLenc.def}[1994/12/14 Standard LaTeX file]
\DeclareFontEncoding{OML}{}{}
\DeclareTextAccent{\t}{OML}{"7F}
\endinput
%% 
%% End of file `OMLenc.def'.
